@@ -136,7 +136,7 @@ impl AliasRoot {
             let base_len = args.len() - remaining_args.len();
             let base_args = args.iter().take(base_len).map(AsRef::as_ref);
             let after_args = alias.after.iter().map(AsRef::as_ref);
-            let remaining_args = remaining_args.iter().map(AsRef::as_ref).skip(1);
+            let remaining_args = remaining_args[1..].iter().map(AsRef::as_ref);
             let new_args = base_args.chain(after_args).chain(remaining_args);
 
             // log::trace!("新的參數為 {:?}", new_args);
@@ -279,8 +279,8 @@ pub enum Subs {
 #[derive(StructOpt, Debug, Serialize)]
 pub enum History {
     RM {
-        #[structopt(parse(try_from_str))]
-        script: ScriptQuery,
+        #[structopt(parse(try_from_str), required = true, min_values = 1)]
+        queries: Vec<ListQuery>,
         range: RangeQuery,
     },
     // TODO: 好想把它寫在 history rm 裡面...
@@ -293,7 +293,7 @@ pub enum History {
     Humble { event_id: u64 },
     Show {
         #[structopt(default_value = "-", parse(try_from_str))]
-        script: ScriptQuery,
+        queries: Vec<ListQuery>,
         #[structopt(short, long, default_value = "10")]
         limit: u32,
         #[structopt(long)]
