@@ -7,7 +7,7 @@ use hyper_scripter::error::{Error, RedundantOpt, Result};
 use hyper_scripter::extract_msg::{extract_env_from_content, extract_help_from_content};
 use hyper_scripter::list::{fmt_list, DisplayIdentStyle, DisplayStyle, ListOptions};
 use hyper_scripter::path;
-use hyper_scripter::query::{self, RangeQuery, ScriptQuery};
+use hyper_scripter::query::{self, ScriptQuery};
 use hyper_scripter::script_repo::{RepoEntry, ScriptRepo};
 use hyper_scripter::script_time::ScriptTime;
 use hyper_scripter::tag::{Tag, TagFilter};
@@ -18,7 +18,7 @@ use hyper_scripter::util::{
 };
 use hyper_scripter::Either;
 use hyper_scripter::{db, migration};
-use hyper_scripter_historian::Historian;
+use hyper_scripter_historian::{Historian, IgnoreResult};
 
 #[tokio::main]
 async fn main() {
@@ -204,6 +204,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             let (path, mut entry) =
                 main_util::edit_or_create(edit_query, &mut repo, ty, edit_tags).await?;
             let prepare_resp = util::prepare_script(&path, &*entry, no_template, &content)?;
+            entry.update(|info| info.read()).await?;
             if !fast {
                 let res = util::open_editor(&path);
                 if let Err(err) = res {
@@ -212,6 +213,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             }
             let should_keep = main_util::after_script(&mut entry, &path, &prepare_resp).await?;
             if !should_keep {
+                util::remove(&path)?;
                 let id = entry.id;
                 repo.remove(id).await?
             }
@@ -226,11 +228,15 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             let content = util::read_file(&script_path)?;
 
             let helps = extract_help_from_content(&content);
-            print_iter(helps, "\n");
-            println!("");
+            let has_help = print_iter(helps, "\n");
 
-            let envs = extract_env_from_content(&content);
-            print_iter(envs, "\n");
+            let mut envs = extract_env_from_content(&content).peekable();
+            if envs.peek().is_some() {
+                if has_help {
+                    println!("\n");
+                }
+                print_iter(envs, "\n");
+            }
         }
         Subs::Run {
             script_query,
@@ -278,9 +284,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             let script_path = path::open_script(&entry.name, &entry.ty, Some(true))?;
             let content = util::read_file(&script_path)?;
             let envs = extract_env_from_content(&content);
-            for msg in envs {
-                println!("{}", msg);
-            }
+            print_iter(envs, "\n");
         }
         Subs::Types(Types {
             subcmd: Some(TypesSubs::LS),
@@ -317,11 +321,11 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             let opt = ListOptions {
                 grouping: grouping.into(),
                 plain,
-                queries: &queries,
+                queries,
                 display_style,
             };
             let stdout = std::io::stdout();
-            fmt_list(&mut stdout.lock(), &mut repo.init().await?, &opt).await?;
+            fmt_list(&mut stdout.lock(), &mut repo.init().await?, opt).await?;
         }
         Subs::RM { queries, purge } => {
             let mut repo = repo.init().await?;
@@ -505,24 +509,34 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             }
         }
         Subs::History {
-            subcmd: History::RM { script, range },
+            subcmd: History::RM { queries, range },
         } => {
             let mut repo = repo.init().await?;
             let historian = repo.historian().clone();
-            let mut entry = query::do_script_query_strict(&script, &mut repo).await?;
-            let res = match range {
-                RangeQuery::Single(n) => historian.ignore_args(entry.id, n).await?,
-                RangeQuery::Range { min, max } => {
-                    historian.ignore_args_range(entry.id, min, max).await?
+            let mut scripts = query::do_list_query(&mut repo, &queries).await?;
+            let ids: Vec<_> = scripts.iter().map(|s| s.id).collect();
+            let res_vec = historian
+                .ignore_args_range(&ids, range.get_min(), range.get_max())
+                .await?;
+            // TODO: 測試多個腳本的狀況
+            for (entry, res) in scripts.iter_mut().zip(res_vec) {
+                // TODO: 平行？
+                if check_time_changed(&entry, &res) {
+                    log::debug!(
+                        "刪除後時間不同 {:?} {:?} {:?} v.s. {:?}",
+                        entry.exec_time,
+                        entry.exec_done_time,
+                        entry.humble_time,
+                        res
+                    );
+                    entry
+                        .update(|info| {
+                            info.exec_time = res.exec_time.map(|t| ScriptTime::new(t));
+                            info.exec_done_time = res.exec_done_time.map(|t| ScriptTime::new(t));
+                            info.humble_time = res.humble_time;
+                        })
+                        .await?;
                 }
-            };
-            if let Some(res) = res {
-                entry
-                    .update(|info| {
-                        info.exec_time = res.exec_time.map(|t| ScriptTime::new(t));
-                        info.exec_done_time = res.exec_done_time.map(|t| ScriptTime::new(t));
-                    })
-                    .await?;
             }
         }
         Subs::History {
@@ -563,7 +577,7 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
         Subs::History {
             subcmd:
                 History::Show {
-                    script,
+                    queries,
                     limit,
                     with_name,
                     offset,
@@ -573,14 +587,16 @@ async fn main_inner(root: Root) -> Result<MainReturn> {
             let mut repo = repo.init().await?;
             let historian = repo.historian().clone();
             let dir = util::option_map_res(dir, |d| path::normalize_path(d))?;
-            let entry = query::do_script_query_strict(&script, &mut repo).await?;
+            let scripts = query::do_list_query(&mut repo, &queries).await?;
+            let ids: Vec<_> = scripts.iter().map(|s| s.id).collect();
             let args_list = historian
-                .previous_args_list(entry.id, limit, offset, dir.as_deref())
+                .previous_args_list(&ids, limit, offset, dir.as_deref())
                 .await?;
-            for args in args_list {
-                log::debug!("嘗試打印參數 {}", args);
+            for (script_id, args) in args_list {
+                log::debug!("嘗試打印參數 {} {}", script_id, args);
                 let args: Vec<String> = serde_json::from_str(&args)?;
                 if with_name {
+                    let entry = get_mut_by_id(&mut repo, script_id)?;
                     print!("{}", entry.name.key());
                     if !args.is_empty() {
                         print!(" ");
@@ -633,16 +649,32 @@ async fn process_event_by_id(is_humble: bool, repo: RepoHolder, event_id: u64) -
         historian.ignore_args_by_id(event_id).await?
     };
     if let Some(res) = res {
-        let mut entry = repo.get_mut_by_id(res.script_id).ok_or_else(|| {
-            log::error!("史學家給的腳本 id 竟然在倉庫中找不到……");
-            Error::ScriptNotFound(res.script_id.to_string())
-        })?;
+        let mut entry = get_mut_by_id(&mut repo, res.script_id)?;
         entry
             .update(|info| {
                 info.exec_time = res.exec_time.map(|t| ScriptTime::new(t));
                 info.exec_done_time = res.exec_done_time.map(|t| ScriptTime::new(t));
+                info.humble_time = res.humble_time;
             })
             .await?;
     }
     Ok(())
 }
+
+fn get_mut_by_id(repo: &mut ScriptRepo, id: i64) -> Result<RepoEntry<'_>> {
+    repo.get_mut_by_id(id).ok_or_else(|| {
+        log::error!("史學家給的腳本 id 竟然在倉庫中找不到……");
+        Error::ScriptNotFound(id.to_string())
+    })
+}
+
+fn check_time_changed(entry: &RepoEntry<'_>, ignrore_res: &IgnoreResult) -> bool {
+    let s_exec_time = entry.exec_time.as_ref().map(|t| **t);
+    let s_exec_done_time = entry.exec_done_time.as_ref().map(|t| **t);
+    (s_exec_time, s_exec_done_time, entry.humble_time)
+        != (
+            ignrore_res.exec_time,
+            ignrore_res.exec_done_time,
+            ignrore_res.humble_time,
+        )
+}
