@@ -1,6 +1,9 @@
 mod list_impl;
 pub use list_impl::*;
 
+mod grid;
+pub use grid::Grid;
+
 mod tree;
 mod tree_lib;
 
@@ -80,9 +83,9 @@ impl FromStr for Grouping {
 }
 
 #[derive(Debug)]
-pub struct ListOptions<'a, T = (), U = ()> {
+pub struct ListOptions<T = (), U = ()> {
     pub grouping: Grouping,
-    pub queries: &'a [ListQuery],
+    pub queries: Vec<ListQuery>,
     pub plain: bool,
     pub display_style: DisplayStyle<T, U>,
 }
