@@ -8,26 +8,26 @@ const DEFAULT_WELCOME_MSG: &str = "{{#each content}}{{{this}}}
 {{/each}}";
 
 const SHELL_WELCOME_MSG: &str = "# [HS_HELP]: Help message goes here...
-# [HS_ENV_HELP]: VAR - Help message for env var `VAR` goes here
+# [HS_ENV_HELP]: VAR -> Help message for env var `VAR` goes here
 
 set -e
-{{#if birthplace_in_home}}
-cd ~/{{birthplace}}
+{{#if birthplace_rel_in_home}}
+cd ~/{{birthplace_rel}}
 {{else}}
-cd {{birthplace_abs}}
+cd {{birthplace}}
 {{/if}}
 {{#each content}}{{{this}}}
 {{/each}}";
 
 const JS_WELCOME_MSG: &str = "// [HS_HELP]: Help message goes here...
-// [HS_ENV_HELP]: VAR - Help message for env var `VAR` goes here
+// [HS_ENV_HELP]: VAR -> Help message for env var `VAR` goes here
 
 process.chdir(require('os').homedir());
-{{#if birthplace_in_home}}
+{{#if birthplace_rel_in_home}}
 process.chdir(process.env.HOME);
-process.chdir('{{birthplace}}');
+process.chdir('{{birthplace_rel}}');
 {{else}}
-process.chdir('{{birthplace_abs}}');
+process.chdir('{{birthplace}}');
 {{/if}}
 let spawn = require('child_process').spawnSync;
 spawn('test', [], { stdio: 'inherit' });
@@ -39,7 +39,7 @@ writeFile('/dev/null', 'some content');
 {{/each}}";
 
 const TMUX_WELCOME_MSG: &str = "# [HS_HELP]: Help message goes here...
-# [HS_ENV_HELP]: VAR - Help message for env var `VAR` goes here
+# [HS_ENV_HELP]: VAR -> Help message for env var `VAR` goes here
 
 NAME=${NAME/./_}
 tmux has-session -t $NAME
@@ -50,10 +50,10 @@ if [ $? = 0 ]; then
 fi
 
 set -e
-{{#if birthplace_in_home}}
-cd ~/{{birthplace}}
+{{#if birthplace_rel_in_home}}
+cd ~/{{birthplace_rel}}
 {{else}}
-cd {{birthplace_abs}}
+cd {{birthplace}}
 {{/if}}
 tmux new-session -s $NAME -d \"{{{content.0}}}; $SHELL\" || exit 1
 tmux split-window -h \"{{{content.1}}}; $SHELL\"
@@ -62,11 +62,11 @@ tmux split-window -h \"{{{content.1}}}; $SHELL\"
 tmux -2 attach-session -d";
 
 const RB_WELCOME_MSG: &str = "# [HS_HELP]: Help message goes here...
-# [HS_ENV_HELP]: VAR - Help message for env var `VAR` goes here
-{{#if birthplace_in_home}}
-Dir.chdir(\"#{ENV['HOME']}/{{birthplace}}\")
+# [HS_ENV_HELP]: VAR -> Help message for env var `VAR` goes here
+{{#if birthplace_rel_in_home}}
+Dir.chdir(\"#{ENV['HOME']}/{{birthplace_rel}}\")
 {{else}}
-Dir.chdir(\"{{birthplace_abs}}\")
+Dir.chdir(\"{{birthplace}}\")
 {{/if}}
 {{#each content}}{{{this}}}
 {{/each}} ";
@@ -181,7 +181,7 @@ create_default_types! {
         args: vec!["{{path}}".to_owned()],
         env: vec![(
             "NODE_PATH".to_owned(),
-            "{{{hs_home}}}/node_modules".to_owned(),
+            "{{{home}}}/node_modules".to_owned(),
         )],
     }),
     ("js-i", JS_WELCOME_MSG, ScriptTypeConfig {
@@ -191,7 +191,7 @@ create_default_types! {
         args: vec!["-i".to_owned(), "-e".to_owned(), "{{{content}}}".to_owned()],
         env: vec![(
             "NODE_PATH".to_owned(),
-            "{{{hs_home}}}/node_modules".to_owned(),
+            "{{{home}}}/node_modules".to_owned(),
         )],
     }),
     ("rb", RB_WELCOME_MSG, ScriptTypeConfig {
