@@ -205,9 +205,8 @@ fn run(
     let env = conf.gen_env(&info)?;
     let ty_env = script_conf.gen_env(&info)?;
 
-    let pre_run_script = prepare_pre_run()?;
-    let args = std::iter::once(pre_run_script.as_ref()).chain(remaining_iter!());
-    let mut cmd = super::create_cmd("bash", args);
+    let pre_run_script = prepare_pre_run(None)?;
+    let mut cmd = super::create_cmd(pre_run_script, remaining_iter!());
     cmd.envs(ty_env.iter().map(|(a, b)| (a, b)));
     cmd.envs(env.iter().map(|(a, b)| (a, b)));
 
@@ -326,11 +325,17 @@ pub async fn load_utils(script_repo: &mut ScriptRepo) -> Result {
     Ok(())
 }
 
-pub fn prepare_pre_run() -> Result<PathBuf> {
+pub fn prepare_pre_run(content: Option<&str>) -> Result<PathBuf> {
     let p = path::get_home().join(path::HS_PRE_RUN);
-    if !p.exists() {
-        log::info!("寫入預執行腳本 {:?}", p);
-        super::write_file(&p, include_str!("hs_prerun.sh"))?;
+    if content.is_some() || !p.exists() {
+        let content = content.unwrap_or_else(|| include_str!("hs_prerun"));
+        log::info!("寫入預執行腳本 {:?} {}", p, content);
+        super::write_file(&p, content)?;
+        #[cfg(target_os = "linux")]
+        {
+            use std::os::unix::fs::PermissionsExt;
+            std::fs::set_permissions(&p, std::fs::Permissions::from_mode(0o774))?;
+        }
     }
     Ok(p)
 }
@@ -373,6 +378,7 @@ pub async fn after_script(
     path: &Path,
     prepare_resp: &PrepareRespond,
 ) -> Result<bool> {
+    let mut record_write = true;
     match prepare_resp {
         PrepareRespond::HasContent => {
             log::debug!("帶內容腳本，不執行後處理");
@@ -380,18 +386,18 @@ pub async fn after_script(
         PrepareRespond::NoContent { is_new, time } => {
             let modified = super::file_modify_time(path)?;
             if time >= &modified {
-                return Ok(if *is_new {
+                if *is_new {
                     log::info!("新腳本未變動，應刪除之");
-                    super::remove(path)?;
-                    false
+                    return Ok(false);
                 } else {
-                    log::info!("舊本未變動，不記錄事件");
-                    // FIXME: 其實應該記錄一筆讀取事件…
-                    true
-                });
+                    log::info!("舊腳本未變動，不記錄寫事件（只記讀事件）");
+                    record_write = false;
+                }
             }
         }
     }
-    entry.update(|info| info.write()).await?;
+    if record_write {
+        entry.update(|info| info.write()).await?;
+    }
     Ok(true)
 }
