@@ -26,6 +26,7 @@ fn get_exe() -> String {
 pub struct RunEnv {
     pub home: Option<PathBuf>,
     pub dir: Option<PathBuf>,
+    pub silent: Option<bool>,
 }
 
 #[macro_export]
@@ -140,7 +141,10 @@ pub fn run_with_env<T: ToString>(env: RunEnv, args: T) -> Result<String> {
     let args_vec: Vec<&str> = if args.find('|').is_some() {
         let (first, second) = args.split_once("|").unwrap();
         let mut v: Vec<_> = first.split(' ').filter(|s| !s.is_empty()).collect();
-        v.push(second.trim());
+        let second = second.trim();
+        if second.len() > 0 {
+            v.push(second);
+        }
         v
     } else {
         args.split_whitespace().collect()
@@ -163,11 +167,14 @@ pub fn run_with_env<T: ToString>(env: RunEnv, args: T) -> Result<String> {
     let stdout = child.stdout.as_mut().unwrap();
     let mut out_str = vec![];
     let reader = BufReader::new(stdout);
+    let silent = env.silent;
     reader
         .lines()
         .filter_map(|line| line.ok())
         .for_each(|line| {
-            println!("{}", line);
+            if silent != Some(true) {
+                println!("{}", line);
+            }
             out_str.push(line);
         });
 
@@ -189,7 +196,7 @@ fn get_ls(filter: Option<&str>, query: Option<&str>) -> Vec<String> {
     )
     .unwrap();
     ls_res
-        .split(' ')
+        .split_whitespace()
         .filter_map(|s| {
             if !s.is_empty() {
                 Some(s.to_owned())
